@@ -3,6 +3,8 @@ export const CHAR_LIMIT = 100_00;
 export const API_VERSION = "3.5.34";
 
 export const COMPLETION_CHARS =
-  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ(=[%/{+#.,\\<+-|&*%=$#@!";
+  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ(=[%/{+#.,\\<+-|&*=$#@!";
 
 export const MAX_RESULTS = 5;
+
+export const TABNINE_LOGO = "⌬";
